Maat Framework
Maat is a full-stack backend framework for Dart with routing, middleware, validation, authentication, console commands, bounded and streaming request bodies, multi-isolate workers, and graceful shutdown.
import 'package:maat/maat.dart';
Route.get('/health', (Request request) => {'status': 'ok'});
await app.serve();
Create a project with Ptah:
dart pub global activate maat_ptah
maat new blog