TestClient class

Calls the HTTP kernel in-process, no sockets. Laravel's $this->get('/').

Constructors

TestClient(Application app, [Map<String, String>? headers])

Properties

app Application
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, {Map<String, String>? headers}) Future<TestResponse>
deleteJson(String path, [Object? body, Map<String, String>? headers]) Future<TestResponse>
get(String path, {Map<String, String>? headers}) Future<TestResponse>
json(String method, String path, [Object? body, Map<String, String>? headers]) Future<TestResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchJson(String path, [Object? body, Map<String, String>? headers]) Future<TestResponse>
post(String path, {Map<String, String>? form, Map<String, String>? headers}) Future<TestResponse>
postJson(String path, [Object? body, Map<String, String>? headers]) Future<TestResponse>
putJson(String path, [Object? body, Map<String, String>? headers]) Future<TestResponse>
toString() String
A string representation of this object.
inherited
withHeader(String name, String value) TestClient
withHeaders(Map<String, String> headers) TestClient
withToken(String token) TestClient

Operators

operator ==(Object other) bool
The equality operator.
inherited